@@ -9,6 +9,15 @@ use Storable qw( freeze thaw );
 use HTTP::Date qw( time2iso str2time );
 use Scalar::Util 'weaken';
 
+our %DBI_OPTIONS = (
+  FetchHashKeyName    => 'NAME_lc',
+  ShowErrorStatement  => 1,
+  ChopBlanks          => 1,
+  AutoCommit          => 1,
+  RaiseError          => 1,
+  RootClass           => 'DBIx::ContextualFetch',
+);
+
 
 #==============================================================================
 sub new
@@ -19,9 +28,11 @@ sub new
   my $conn = $s->context->config->data_connections->session;
   
   local $^W = 0;
-  __PACKAGE__->set_db('Main', $conn->dsn,
+  __PACKAGE__->set_db('Main',
+    $conn->dsn,
     $conn->username,
-    $conn->password
+    $conn->password,
+#    \%DBI_OPTIONS
   );
   
   # Prepare our Session:
